sequencetools.partition_sequence_by_weights_exactly
===================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_by_weights_exactly.partition_sequence_by_weights_exactly
